@@ -1,9 +1,9 @@
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-[assembly:AssemblyVersion("1.0.0.0")]
+[assembly:AssemblyVersion("2.0.0.76")]
 [assembly:AssemblyTitle("Mono.Zeroconf")]
 [assembly:AssemblyDescription("Cross Platform Zeroconf for .NET")]
-[assembly:AssemblyCopyright("Copyright (C) 2006-2007 Novell, Inc.")]
-[assembly:AssemblyCompany("Novell, Inc")]
+[assembly:AssemblyCopyright("Copyright (C) 2006-2008 Novell, Inc.")]
+[assembly:AssemblyCompany("Novell, Inc.")]
 
